##  Integration Use Case: Technology Risk and Compliance
Most companies are much better at introducing new technologies than retiring them. When out-of-date systems remain live, it can be a feeding frenzy for cyberattacks or pose a threat of service outages – both of which lead to significant (and costly) disruption of operations. That’s what makes technology risk management so important for maintaining compliance.
The responsibility of Technology Risk and Compliance largely falls on CIOs and CISOs, but enterprise architects also play a major part. The integration of SAP LeanIX and Apptio helps to minimize migration costs from retiring legacy IT components and reducing the support costs associated with keeping outdated systems live. It does so by empowering EAs to:
  * Increase visibility into legacy technologies and their financial impact on the business
  * Minimize migration costs while moving data between IT components
  * Reduce support costs associated with keeping outdated technologies active
